wcwidth: Measures the displayed width of unicode strings in a terminal
======================================================================

Description
-----------

Measures the displayed width of unicode strings in a terminal

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/wcwidth/

